@@ -3,7 +3,7 @@ package LWP::UserAgent::Plugin;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-08-13'; # DATE
 our $DIST = 'LWP-UserAgent-Plugin'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -48,9 +48,12 @@ sub set_plugins {
 sub _run_hooks {
     my ($self, $hook, $opts, $r) = @_;
 
+    log_trace "[LWP::UserAgent::Plugin] -> running hook %s", $hook if $ENV{LWP_USERAGENT_PLUGIN_TRACE};
+
     my $status;
     for my $p (@plugins) {
         next unless $p->[0]->can($hook);
+        log_trace "[LWP::UserAgent::Plugin]   -> handler from plugin %s", $p->[0] if $ENV{LWP_USERAGENT_PLUGIN_TRACE};
         local $r->{config} = $p->[1];
         local $r->{hook} = $hook;
         $status = $p->[0]->$hook($r);
@@ -59,7 +62,9 @@ sub _run_hooks {
         }
         last if $status == 98 || $status == 99;
     }
-    $status // -1;
+    $status //= -1;
+    log_trace "[LWP::UserAgent::Plugin] <- return hook %s, status %d", $hook, $status if $ENV{LWP_USERAGENT_PLUGIN_TRACE};
+    $status;
 }
 
 sub request {
@@ -101,7 +106,7 @@ LWP::UserAgent::Plugin - LWP::UserAgent with plugins
 
 =head1 VERSION
 
-This document describes version 0.002 of LWP::UserAgent::Plugin (from Perl distribution LWP-UserAgent-Plugin), released on 2020-08-13.
+This document describes version 0.003 of LWP::UserAgent::Plugin (from Perl distribution LWP-UserAgent-Plugin), released on 2020-08-13.
 
 =head1 SYNOPSIS
 
@@ -276,6 +281,10 @@ configure the plugin.
 
 =head1 ENVIRONMENT
 
+=head2 LWP_USERAGENT_PLUGIN_TRACE
+
+Bool. If set to true, will produce more trace log statements.
+
 =head2 LWP_USERAGENT_PLUGINS
 
 A JSON-encoded array. If set, will call L</set_plugins> with the decoded value.
